---
search:
  exclude: true
---
# コード例

[リポジトリ](https://github.com/openai/openai-agents-python/tree/main/examples) の examples セクションでは、さまざまな SDK のサンプル実装をご覧いただけます。これらのコード例は、さまざまなパターンや機能を示す複数のカテゴリーに整理されています。


## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**
  このカテゴリーの例では、次のような一般的なエージェントの設計パターンを説明します。

    - 決定論的なワークフロー
    - ツールとしての エージェント
    - エージェントの並列実行

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**
  このカテゴリーでは、次のような SDK の基礎的な機能を紹介します。

    - 動的な system prompt
    - ストリーミング出力
    - ライフサイクルイベント

- **[tool examples](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**
  OpenAI がホストするツール（ Web 検索 や ファイル検索 など）の実装方法を学び、
   それらを エージェント に統合する方法を示します。

- **[model providers](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**
  OpenAI 以外のモデルを SDK で使用する方法を紹介します。

- **[handoffs](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**
  エージェントのハンドオフ の実用的な例をご覧ください。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**
  MCP を使って エージェント を構築する方法を学べます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**
  実運用のユースケースを示す、作り込まれたコード例が 2 つあります。

    - **customer_service**: 航空会社向けのカスタマーサービス システムの例。
    - **research_bot**: シンプルな ディープリサーチ クローン。

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**
  TTS と STT モデルを使用した音声 エージェントの例をご覧ください。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**
  SDK を使ってリアルタイムな体験を構築する例を紹介します。